NetQASM (0.0.1)
===============

Welcome to `NetQASM`'s README.

`NetQASM` is a low-level instruction set architecture for hybrid quantum-classical programs in a quantum internet.

This is a placeholder for the WIP package.
